## Hypothesis Validation

### Current Hypothesis

This is the current hypothesis we are working on:

{current_hypothesis}

### Team

To answer this question we have assembled the following team:

{team_description}


### Initial Facts

Here is an initial fact sheet to consider:

{fact_sheet}
